@@ -24,4 +24,9 @@ FILE_AND_TAG_PAIRS = [
 EXECUTOR_FOLDER_v1 = 'executor_v1'
 EXECUTOR_FOLDER_v2 = 'executor_v2'
 
-FLOW_URL_PLACEHOLDER = 'jcloud.jina.ai'
\ No newline at end of file
+FLOW_URL_PLACEHOLDER = 'jcloud.jina.ai'
+
+PRICING_GPT4_PROMPT = 0.03
+PRICING_GPT4_GENERATION = 0.06
+PRICING_GPT3_5_TURBO_PROMPT = 0.002
+PRICING_GPT3_5_TURBO_GENERATION = 0.002
\ No newline at end of file
